@@ -1,6 +1,9 @@
 package Reddit::Client;
 
-our $VERSION = '1.231';
+our $VERSION = '1.242';
+# 1.242 request_errors (print the content of errors) is now true by default.
+# 1.24 ban function
+# 1.241 fix newline in request->send
 # be pretty amazed if we didn't break anything 
 # 1.23 get_modmail_raw
 #	   get_refresh_token
@@ -116,6 +119,7 @@ use constant API_APPROVE             => 35;
 use constant API_IGNORE_REPORTS      => 36;
 use constant API_GETWIKI             => 37;
 use constant API_GET_MODMAIL         => 38;
+use constant API_BAN                 => 39;
 
 #===============================================================================
 # Parameters
@@ -168,6 +172,7 @@ $API[API_REMOVE        ] = ['POST', '/api/remove'             ];
 $API[API_APPROVE       ] = ['POST', '/api/approve'            ];
 $API[API_IGNORE_REPORTS] = ['POST', '/api/ignore_reports'     ];
 $API[API_GET_MODMAIL   ] = ['GET',  '/api/mod/conversations'  ];
+$API[API_BAN           ] = ['POST', '/r/%s/api/friend'        ];
 
 #===============================================================================
 # Class methods
@@ -178,7 +183,7 @@ use fields (
     'cookie',       # store user cookie
     'session_file', # path to session file
     'user_agent',   # user agent string
-    'token',	# oauth authorization token
+    'token',		# oauth authorization token
     'tokentype',    # unused but saved for reference
     'last_token',	# time last token was acquired
     'client_id',	# These 4 values saved for automatic token refreshing
@@ -200,9 +205,9 @@ sub new {
 		 croak "param 'user_agent' is required.";
 	}
 	$self->{user_agent} 	= $param{user_agent};
-	$self->{request_errors} = $param{request_errors} || 0;
+	$self->{request_errors} = $param{request_errors} || 1;
 	$self->{print_response} = $param{print_response} || 0;
-	$self->{print_request}  = $param{print_request}  || 0;
+	$self->{print_request}  = $param{print_request} || 0;
 
 	if ($param{username} or $param{password}) {
 		if (!$param{username} or !$param{password}) {
@@ -744,12 +749,62 @@ sub ignore_reports {
 	my $self = shift;
 	my $fullname = shift || croak "arg 1 (fullname) is required.";
 	
-    	my $result = $self->api_json_request(
+	my $result = $self->api_json_request(
 		api  => API_IGNORE_REPORTS,
 		data => { id => $fullname },
 	);
 	return $result;
 }
+# ban uses the "modcontributors" oauth scope
+sub ban {
+	my ($self, %param) = @_;
+	my $sub	= $param{sub} || $param{subreddit} || die "subreddit is required\n";
+	
+	my $data = { api_type => 'json' };
+	$data->{name}	= $param{username} || die "username is required\n";
+	# ban_context = fullname, but of what - not required
+
+	# Ban message
+	$data->{ban_message} = $param{ban_message} if $param{ban_message};
+	# Reason: matches short report reason
+	if ($param{reason}) { 
+		if (length $param{reason} > 100) {
+			print "Warning: 'reason' longer than 100 characters. Truncating.\n";
+			$param{reason} = substr $param{reason}, 0, 100;
+		}
+		$data->{ban_reason} = $param{reason};
+	}
+
+	if ($param{note}) {
+		if (length $param{note} > 300) {
+			print "Warning: 'note' longer than 300 characters. Truncating.\n";
+			$param{note} = substr $param{note}, 0, 300;
+		}
+		$data->{note} = $param{note};
+	}
+
+	# $data->{container} not needed unless mode is friend or enemy
+	if ($param{duration}){
+		if ($param{duration} > 999) {
+			print "Warning: Max duration is 999. Setting to 999.\n";
+			$param{duration} = 999;
+		} elsif ($param{duration} < 1) {
+			print "Warning: min duration is 1. Setting to indefinite.\n";
+			$param{duration} = 0;
+		}
+		$data->{duration} = $param{duration} if $param{duration};
+	}
+	# $data->{permissions} = ?
+	# type: one of (friend, moderator, moderator_invite, contributor, banned, muted, wikibanned, wikicontributor)
+	$data->{type} = 'banned';
+
+	my $result = $self->api_json_request(
+		api  => API_BAN, 
+		args => [$sub],
+		data => $data,
+	);
+	return $result;
+}
 # modqueue 
 sub get_modlinks {
     	my ($self, %param) = @_;
@@ -758,7 +813,7 @@ sub get_modlinks {
 	my $sub   = $param{sub} || $param{subreddit} || 'mod';
 	my $mode  = $param{mode} || 'modqueue';
 
-    	my $result = $self->api_json_request(
+	my $result = $self->api_json_request(
 		api  => API_MODQ, 
 		args => [$sub, $mode],
 		data => $query,
