@@ -118,14 +118,8 @@ sub send {
 		if ($self->{request_errors}) {
 			croak "Request error: HTTP ".$res->status_line .", Content: $res->{_content}";
 		} else {
-			croak sprintf("Request error: HTTP %s\n", $res->status_line);
+			croak sprintf("Request error: HTTP %s", $res->status_line);
 		}
-
-		#print "-- test -- \n";
-		#print Dumper($request);
-		#print Dumper($res);
-		# print_request overrides print_response since it contains the response
-		#die;	
     }
 }
 
@@ -149,14 +143,13 @@ sub token_request {
 
 	$req->content($postdata);
 
-    	my $res = $ua->request($req);
-	#dd $res;
+	my $res = $ua->request($req);
 
-    	if ($res->is_success) {
-        	return $res->decoded_content;
-    	} else {
-        	croak sprintf('Request error: HTTP %s', $res->status_line);
-    	}
+	if ($res->is_success) {
+		return $res->decoded_content;
+	} else {
+		croak sprintf('Request error: HTTP %s', $res->status_line);
+	}
 }
 
 sub refresh_token_request {
@@ -188,20 +181,20 @@ sub refresh_token_request {
 
     my $result = $ua->request($request);
 
+	if ($data{print_request}) {
+		print Dumper($request);
+		print Dumper($result);
+	}
+
     if ($result->is_success) {
         my $j = decode_json $result->content;
         my $tok = $j->{refresh_token};
 
 		return $tok;
     } else {
-        print "refresh_token_request: something went wrong\n";
-		print $result->status_line;
-		print $result->{_content};
+		print "Request error: HTTP ".$result->status_line.", Content:\n$result->{_content}\n";
+        print "refresh_token_request: something went wrong. To aid in debugging, you can set 'print_request' to true when creating a new Reddit::Client object. This will print the entire content of the request and response.\n";
 
-		if ($data{request_errors}) {
-			print Dumper($request);
-			print Dumper($result);
-		}
 		die;
     }
 
